<?php
/**
 * Check if the request expects JSON
 *
 * @return bool
 */
function expectsJson()
{
    return $_SERVER['HTTP_ACCEPT'] == 'application/json';
}

/**
 * Respond with json data
 *
 * @param $data
 * @param int $statusCode
 */
function jsonResponse($data, $statusCode = 200)
{
    ob_clean();
    header_remove();
    header("Content-type: application/json; charset=utf-8");
    http_response_code($statusCode);
    echo json_encode($data);
    exit();
}

/**
 * Check the session
 *
 * @return bool
 */
function isValidSession()
{
    global $error, $success;
    if (!isset($_POST['id']) || $_POST['id'] !== session_id()) {
        if (expectsJson()) {
            jsonResponse([
                'success' => false,
                'data' => [],
                'error' => 'You have already sent us a contact request'
            ], 500);
            return false;
        }
        $error = 'You have already sent us a contact request';
        $success = false;
        return false;
    }

    if (isset($_SESSION[SESSION_CONTACT_TIME_VAR_NAME]) && time() < $_SESSION[SESSION_CONTACT_TIME_VAR_NAME]){
        // too early to send
        if (expectsJson()) {
            jsonResponse([
                'success' => false,
                'data' => [],
                'error' => 'You have already sent us a contact request'
            ], 500);
            return false;
        }
        else {
            $error = 'You have already sent us a contact request';
            $success = false;
            return false;
        }
    }
    return true;
}

/**
 * Set the session timer once we send successfully
 */
function setSessionTimer()
{
    $_SESSION[SESSION_CONTACT_TIME_VAR_NAME] = time() + SEND_MAIL_EVERY;
}
