<?php
register_nav_menus();

add_theme_support( 'post-thumbnails' );

/**
 * Service Function to call curl
 *
 * @param $url
 * @param array $parameter
 * @param bool $post
 *
 * @return array|mixed
 */
function curlCall( $url, $parameter = [], $post = true )
{
    try {
        $ch = curl_init();
        curl_setopt( $ch, CURLOPT_RETURNTRANSFER, 1 );
        curl_setopt( $ch, CURLOPT_TIMEOUT, 30 );
        if ( $post === true ) {
            curl_setopt( $ch, CURLOPT_POST, 1 );
            curl_setopt( $ch, CURLOPT_POSTFIELDS, $parameter );
        }
        else {
            $url .= '?' . http_build_query( $parameter );
        }
        curl_setopt( $ch, CURLOPT_URL, $url );
        $result = curl_exec( $ch );
        curl_close( $ch );

        return $result;
    } catch ( Exception $exception ) {
        return [
            'Exception Message' => $exception->getMessage(),
            'Exception Trace: ' => $exception->getTraceAsString()
        ];
    }
}


function add_theme_scripts() {
    wp_enqueue_style('font_awesome', PUBLIC_URL.'css/font-awesome.min.css');
    wp_enqueue_style('bs', PUBLIC_URL.'css/bootstrap.min.css');
    wp_enqueue_style('main_style', PUBLIC_URL.'css/style.css');
    wp_enqueue_script('jquery_min', PUBLIC_URL.'js/jquery.min.js');

//    if ( is_singular() && comments_open() && get_option( 'thread_comments' ) ) {
//        wp_enqueue_script( 'comment-reply' );
//    }
}
add_action( 'wp_enqueue_scripts', 'add_theme_scripts' );



function add_favicon() {
    echo '<link rel="shortcut icon" type="image/png" href="'.get_stylesheet_directory_uri().'/images/favicon.png" />';
}
add_action('wp_head', 'add_favicon', 20);

add_filter( 'jpeg_quality', create_function( '', 'return 100;' ) );

if ( ! function_exists( 'setupTheme' ) ) :
    /**
     * Sets up theme defaults and registers support for various WordPress features.
     *
     * Note that this function is hooked into the after_setup_theme hook, which
     * runs before the init hook. The init hook is too late for some features, such
     * as indicating support for post thumbnails.
     */
    function setupTheme() {

        /*
         * Let WordPress manage the document title.
         * By adding theme support, we declare that this theme does not use a
         * hard-coded <title> tag in the document head, and expect WordPress to
         * provide it for us.
         */
        add_theme_support( 'title-tag' );

        /*
         * Enable support for Post Thumbnails on posts and pages.
         *
         * @link https://developer.wordpress.org/themes/functionality/featured-images-post-thumbnails/
         */
        add_theme_support( 'post-thumbnails' );
        set_post_thumbnail_size( 1568, 9999 );

        // This theme uses wp_nav_menu() in two locations.
        register_nav_menus(
            array(
                'main' => __( 'Primary Menu', 'twentynineteen' ),
                'footer' => __( 'Footer Menu', 'twentynineteen' ),
                'social' => __( 'Social Links Menu', 'twentynineteen' ),
            )
        );

        /*
         * Switch default core markup for search form, comment form, and comments
         * to output valid HTML5.
         */
        add_theme_support(
            'html5',
            array(
                'search-form',
                'script',
                'style',
            )
        );

        /**
         * Add support for core custom logo.
         *
         * @link https://codex.wordpress.org/Theme_Logo
         */
        add_theme_support(
            'custom-logo',
            array(
                'height'      => 120,
                'width'       => 430,
                'flex-width'  => false,
                'flex-height' => false,
            )
        );

        // Add theme support for selective refresh for widgets.
        add_theme_support( 'customize-selective-refresh-widgets' );

        // Add support for Block Styles.
        add_theme_support( 'wp-block-styles' );

        // Add support for full and wide align images.
        add_theme_support( 'align-wide' );

        // Add support for editor styles.
        add_theme_support( 'editor-styles' );

        // Enqueue editor styles.
        add_editor_style( 'style-editor.css' );


        // Add support for responsive embedded content.
        add_theme_support( 'responsive-embeds' );


    }
endif;
add_action( 'after_setup_theme', 'setupTheme' );


show_admin_bar(false);

//add_action('after_setup_theme', 'remove_admin_bar');
//
//function remove_admin_bar() {
//    if (!current_user_can('administrator') && !is_admin()) {
//        show_admin_bar(false);
//    }
//}

require_once (__DIR__ .'/includes/custom-post-staff.php');
require_once (__DIR__ .'/includes/custom-post-testimonials.php');
require_once (__DIR__ .'/includes/setup-rest-api.php');


?>
